.. -*- mode: rst -*-

People
------

This work is made available by a community of people, amongst within
the `INRIA Parietal Project Team <https://team.inria.fr/parietal/>`_
folks, in
particular:

* `Demian Wassermann <https://pages.saclay.inria.fr/demian.wassermann/>`_
* Valentin Iovene
* Gaston Zanitti
* Matias Schimt
* Nikita Zdainovich
* `Kshitij Chawla <https://github.com/kchawla-pi>`_

Funding
........

This work has been funded by the 
`ERC Starting Grant NeuroLang <https://cordis.europa.eu/project/id/757672>`_ |erc logo|


.. _citing:

Citing Neurolang
------------------------

There is no paper published yet about NeuroLang. But they are upcoming!
Several publications have been produced within this project and are
shown `here <https://pages.saclay.inria.fr/demian.wassermann/neurolang.html>`_


.. |erc logo| image:: logos/LOGO_ERC-FLAG_EU_.jpg
    :height: 50
    :alt: ERC Logo
